'use strict';

exports.__esModule = true;
exports["default"] = void 0;

var _rax = require("rax");

var _raxView = _interopRequireDefault(require("rax-view"));

var _raxFindDomNode = _interopRequireDefault(require("rax-find-dom-node"));

var _universalEnv = require("universal-env");

var _weexBindingx = _interopRequireDefault(require("weex-bindingx"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

// findDOMNode has difference between weex an web
function getEl(el) {
  if (typeof el === 'string' || typeof el === 'number') return el;
  if (!el.current) return null;
  return _universalEnv.isWeex ? (0, _raxFindDomNode["default"])(el.current).ref : (0, _raxFindDomNode["default"])(el.current);
} // judge bindingx support


var isSupportBinding = !!_weexBindingx["default"].isSupportBinding;
/*
{
  type: 'translate',
  in: [0, 660],
  out: [0, 0, 0, -660] // [x1,y1,x2,y2]
}
{
  expression:'y',
  property:'transform.translate'
}
 */

function transformRangeToExpression(params, propertyType) {
  var input = params["in"];
  var output = params.out;
  var result = []; // resolve negative number in expression

  function negative(val) {
    return val < 0 ? Math.abs(val) + "*(0-1)" : "" + val;
  }
  /*
  {out2: 1, out1: 1.3, in2: 0, in1: -150, ratio: -0.0020000000000000005}
  in1 * x + y = out1
  in2 * x + y = out2 => y = out2 - in2 * x
  in1 * x + out2 - in2 * x = out1
  x  = (out1 - out2) / (in1 - in2)
  y = out2 - in2 * (out1 - out2) / (in1 - in2)
   */


  function transformExpression(in1, in2, out1, out2) {
    var inMax = Math.max(in1, in2);
    var inMin = Math.min(in1, in2);
    var outMax = Math.max(out1, out2);
    var outMin = Math.min(out1, out2);
    var inverse = in1 > in2;
    return "min(" + outMax + ",max(" + outMin + ",(y>=" + negative(inMin) + "&&y<=" + negative(inMax) + ")?(y*" + negative((out1 - out2) / (in1 - in2)) + "+" + negative(out2 - in2 * (out1 - out2) / (in1 - in2)) + "):(y<" + negative(inMin) + "?(" + negative(inverse ? out2 : out1) + "):(" + negative(inverse ? out1 : out2) + "))))";
  }

  switch (propertyType) {
    case 'transform':
      if (params.type == 'translate' || params.type == 'scale') {
        var x1 = output[0];
        var y1 = output[1];
        var x2 = output[2];
        var y2 = output[3];
        result.push({
          property: "transform." + params.type + "Y",
          expression: transformExpression(input[0], input[1], y1, y2)
        });
        result.push({
          property: "transform." + params.type + "X",
          expression: transformExpression(input[0], input[1], x1, x2)
        });
      }

      if (params.type == 'rotate') {
        result.push({
          property: "transform." + params.type + "Z",
          expression: transformExpression(input[0], input[1], output[0], output[1])
        });
      }

      break;

    case 'opacity':
      result = [{
        property: 'opacity',
        expression: transformExpression(input[0], input[1], output[0], output[1])
      }];
      break;

    case 'backgroundColor':
      result = [{
        property: 'background-color',
        expression: "evaluateColor('" + output[0] + "','" + output[1] + "'," + transformExpression(input[0], input[1], 0, 1) + ")"
      }];
      break;
  }

  return result;
}

var useEffectOnce = function (effect) {
  (0, _rax.useEffect)(effect, []);
};

var BindingParallax = (0, _rax.forwardRef)(function (props, ref) {
  var parallaxRef = (0, _rax.useRef)(null);

  var className = props.className,
      style = props.style,
      rest = __rest(props, ["className", "style"]);

  useEffectOnce(function () {
    var bindingScroller = props.bindingScroller,
        _props$bindingProps = props.bindingProps,
        bindingProps = _props$bindingProps === void 0 ? [] : _props$bindingProps,
        _props$transform = props.transform,
        transform = _props$transform === void 0 ? [] : _props$transform,
        backgroundColor = props.backgroundColor,
        opacity = props.opacity,
        _props$extraBindingPr = props.extraBindingProps,
        extraBindingProps = _props$extraBindingPr === void 0 ? [] : _props$extraBindingPr;
    var parallax = getEl(parallaxRef);
    transform.forEach(function (trans) {
      transformRangeToExpression(trans, 'transform').forEach(function (r) {
        bindingProps.push({
          element: parallax,
          property: r.property,
          expression: r.expression,
          config: {
            transformOrigin: 'center'
          }
        });
      });
    });

    if (backgroundColor) {
      transformRangeToExpression(backgroundColor, 'backgroundColor').forEach(function (r) {
        bindingProps.push({
          element: parallax,
          property: r.property,
          expression: r.expression
        });
      });
    }

    if (opacity) {
      transformRangeToExpression(opacity, 'opacity').forEach(function (r) {
        bindingProps.push({
          element: parallax,
          property: r.property,
          expression: r.expression
        });
      });
    }

    if (extraBindingProps && extraBindingProps.length) {
      extraBindingProps.forEach(function (prop) {
        prop.element = getEl(prop.element);
      });
    }

    _weexBindingx["default"].bind({
      anchor: bindingScroller,
      eventType: 'scroll',
      props: extraBindingProps && extraBindingProps.length ? [].concat(bindingProps, extraBindingProps) : bindingProps
    });
  });
  (0, _rax.useImperativeHandle)(ref, function () {
    return parallaxRef.current;
  });
  return (0, _rax.createElement)(_raxView["default"], _extends({}, rest, {
    ref: parallaxRef,
    className: className,
    style: style
  }), props.children);
});
BindingParallax.displayName = 'BindingParallax';
var Parallax = (0, _rax.forwardRef)(function (props, ref) {
  var bindingScroller = props.bindingScroller,
      className = props.className,
      style = props.style,
      rest = __rest(props, ["bindingScroller", "className", "style"]);

  var scroller = getEl(bindingScroller);
  if (!scroller) return null;

  if (isSupportBinding || !_universalEnv.isWeex) {
    return (0, _rax.createElement)(BindingParallax, _extends({}, rest, {
      className: className,
      style: style,
      bindingScroller: scroller
    }));
  }

  return _universalEnv.isWeex ? (0, _rax.createElement)("parallax", _extends({
    ref: ref
  }, rest, {
    className: className,
    style: style,
    bindingScroller: scroller
  })) : (0, _rax.createElement)(_raxView["default"], _extends({
    ref: ref
  }, rest, {
    className: className,
    style: style
  }));
});
Parallax.displayName = 'Parallax';
var _default = Parallax;
exports["default"] = _default;